@@ -1,7 +1,8 @@
-from pydispix.client import Client  # noqa
+from pydispix.autodraw import AutoDrawer  # noqa
 from pydispix.canvas import Canvas, Pixel  # noqa
+from pydispix.client import Client  # noqa
 from pydispix.color import Color, Colour, parse_color, parse_colour  # noqa
-from pydispix.ratelimits import RateLimiter, RateLimitedEndpoint  # noqa
 from pydispix.log import setup_logging
+from pydispix.ratelimits import RateLimitedEndpoint, RateLimiter  # noqa
 
 setup_logging()
