@@ -38,20 +38,21 @@ class Client:
         data: Optional[dict] = None,
         params: Optional[dict] = None,
         parse_json: bool = True,
-        ratelimit_after: bool = False
+        ratelimit_after: bool = False,
+        show_progress: bool = False,
     ) -> Union[bytes, dict]:
         if not endpoint_url.startswith("/"):
             endpoint_url = "/" + endpoint_url
 
         if not ratelimit_after:
-            self.rate_limiter.wait(endpoint_url)
+            self.rate_limiter.wait(endpoint_url, show_progress=show_progress)
 
         logger.debug(f'Request: {method} {endpoint_url} data={data!r} params={params!r}.')
 
         response = requests.request(method, self.base_url + endpoint_url, json=data, headers=self.headers, params=params)
         self.rate_limiter.update_from_headers(endpoint_url, response.headers)
         if ratelimit_after:
-            self.rate_limiter.wait(endpoint_url)
+            self.rate_limiter.wait(endpoint_url, show_progress=show_progress)
 
         if parse_json:
             return response.json()
