@@ -36,19 +36,24 @@ class RateLimitedEndpoint:
 
         return self.default_delay
 
-    def wait(self):
+    def sleep(seconds: int, show_progress: bool = False):
+        if show_progress:
+            raise NotImplementedError("show_progress is not yet implemented, it will be added in v0.4.0")
+        time.sleep(seconds)
+
+    def wait(self, *, show_progress: bool = False):
         if not self.rate_limited:
             logger.debug("Sleeping default delay, not rate limited.")
-            return time.sleep(self.default_delay)
+            return self.sleep(self.default_delay, show_progress=show_progress)
         if self.cooldown_time != 0:
             logger.warning(f"Sleeping {self.cooldown_time}s, on cooldown.")
-            return time.sleep(self.cooldown_time)
+            return self.sleep(self.cooldown_time, show_progress=show_progress)
         if self.remaining_requests == 0:
             logger.warning(f"Sleeping {self.reset_time}s, on reset.")
-            return time.sleep(self.reset_time)
+            return self.sleep(self.reset_time, show_progress=show_progress)
 
         logger.debug(f"Sleeping default delay, {self.remaining_requests} requests remaining.")
-        return time.sleep(self.default_delay)
+        return self.sleep(self.default_delay, show_progress=show_progress)
 
 
 class RateLimiter:
@@ -59,6 +64,6 @@ class RateLimiter:
         limiter = self.rate_limits[endpoint]
         limiter.update_from_headers(headers)
 
-    def wait(self, endpoint: str):
+    def wait(self, endpoint: str, show_progress: bool = False):
         limiter = self.rate_limits[endpoint]
-        limiter.wait()
+        limiter.wait(show_progress=show_progress)
